pub trait WithChildrenExt: Render + Sized {
// Provided method
fn with_children(self, children: Markup) -> SlottedComponent<Self> { ... }
}Expand description
Extension trait for attaching slot-aware child markup to a renderable component.
This is the lower-level transport surface for runtime slots. Prefer
ComponentBuilder from maud-extensions for new typed shell/layout
components when the regions can be expressed as fields.
Provided Methods
Sourcefn with_children(self, children: Markup) -> SlottedComponent<Self>
fn with_children(self, children: Markup) -> SlottedComponent<Self>
Renders children into the slot transport expected by slot and named_slot.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.